@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from pymongo.objectid import ObjectId
+from bson.objectid import ObjectId
 
 from scalymongo.document import Document
 from scalymongo.connection import Connection
